pub enum Extends {
Single(String),
Multiple(Vec<String>),
}Expand description
One or more configuration files to extend.
Can be a single path/URL string or an array of paths/URLs. Properties from extended configs are merged, with the current file taking precedence. Earlier entries in an array take priority over later ones.
Supports the ${configDir} variable (resolves to the directory
containing the current config file) and ${originConfigDir} (resolves
to the directory of the original/root config file).
When extending remote configs (URLs), includes and non-Wasm plugins
entries are ignored for security.
Variants
Single(String)
A single file path or URL to a configuration file to extend.
Multiple(Vec<String>)
A collection of file paths and/or URLs to configuration files to extend.