pub struct PluginConfig {
pub locked: Option<bool>,
pub associations: Option<Vec<String>>,
pub settings: BTreeMap<String, Value>,
}Expand description
Configuration for a dprint plugin not covered by the typed plugin structs.
Known plugins (typescript, json, toml, markdown) have dedicated
typed structs. This catch-all is used for any other plugin name.
Fields
locked: Option<bool>Prevent properties in this plugin section from being overridden by extended configurations.
associations: Option<Vec<String>>File patterns to associate with this plugin.
settings: BTreeMap<String, Value>Plugin-specific configuration settings.