pub enum BracePosition {
Maintain,
SameLine,
NextLine,
SameLineUnlessHanging,
}Expand description
Variants
Maintain
Maintains the brace being on the next line or the same line.
SameLine
Forces the brace to be on the same line.
NextLine
Forces the brace to be on the next line.
SameLineUnlessHanging
Forces the brace to be on the next line if the same line is hanging, but otherwise uses the same line.