pub enum OperatorPosition {
Maintain,
SameLine,
NextLine,
}Expand description
Variants
Maintain
Maintains the position of the expression.
SameLine
Forces the whole statement to be on one line.
NextLine
Forces the expression to be on the next line.