pub enum PreferHanging {
Always,
OnlySingleItem,
Never,
}Expand description
Variants
Always
Always prefers hanging regardless of the number of elements.
OnlySingleItem
Only prefers hanging if there is a single item.
Never
Never prefers hanging.