pub enum QuoteStyle {
AlwaysDouble,
AlwaysSingle,
PreferDouble,
PreferSingle,
}Expand description
Variants
AlwaysDouble
Always uses double quotes.
AlwaysSingle
Always uses single quotes.
PreferDouble
Prefers using double quotes except in scenarios where the string contains more double quotes than single quotes.
PreferSingle
Prefers using single quotes except in scenarios where the string contains more single quotes than double quotes.