pub enum SemiColons {
Always,
Prefer,
Asi,
}Expand description
Variants
Always
Always uses semi-colons where applicable.
Prefer
Prefers semi-colons, but doesn’t add one in certain scenarios such as for the last member of a single-line type literal.
Asi
Uses automatic semi-colon insertion. Only adds a semi-colon at the start of some expression statements when necessary. Read more: https://standardjs.com/rules.html#semicolons