pub enum UseBraces {
Maintain,
WhenNotSingleLine,
Always,
PreferNone,
}Expand description
Variants
Maintain
Uses braces if they’re used. Doesn’t use braces if they’re not used.
WhenNotSingleLine
Uses braces when the body is on a different line.
Always
Forces the use of braces. Will add them if they aren’t used.
PreferNone
Forces no braces when the header is one line and body is one line. Otherwise forces braces.