pub struct MarkdownConfig {Show 16 fields
pub locked: Option<bool>,
pub associations: Option<Vec<String>>,
pub deno: Option<bool>,
pub emphasis_kind: Option<StrongKind>,
pub heading_kind: Option<HeadingKind>,
pub ignore_directive: Option<String>,
pub ignore_end_directive: Option<String>,
pub ignore_file_directive: Option<String>,
pub ignore_start_directive: Option<String>,
pub line_width: Option<u32>,
pub new_line_kind: Option<NewLineKind>,
pub strong_kind: Option<StrongKind>,
pub tags: Option<BTreeMap<String, String>>,
pub text_wrap: Option<TextWrap>,
pub unordered_list_kind: Option<UnorderedListKind>,
pub extra: BTreeMap<String, Value>,
}Expand description
Configuration for the dprint Markdown plugin.
Fields
locked: Option<bool>Whether the configuration is not allowed to be overridden or extended.
associations: Option<Vec<String>>File patterns to associate with this plugin.
deno: Option<bool>Top level configuration that sets the configuration to what is used in Deno.
Default: false
emphasis_kind: Option<StrongKind>The character to use for emphasis/italics.
Default: "underscores"
See: https://dprint.dev/plugins/markdown/config/#emphasisKind
heading_kind: Option<HeadingKind>The style of heading to use for level 1 and level 2 headings. Level 3 and higher always use ATX headings.
Default: "atx"
See: https://dprint.dev/plugins/markdown/config/#headingKind
ignore_directive: Option<String>The text to use for an ignore directive (ex. <!-- dprint-ignore -->).
Default: "dprint-ignore"
See: https://dprint.dev/plugins/markdown/config/#ignoreDirective
ignore_end_directive: Option<String>The text to use for an ignore end directive (ex. <!-- dprint-ignore-end -->).
Default: "dprint-ignore-end"
See: https://dprint.dev/plugins/markdown/config/#ignoreEndDirective
ignore_file_directive: Option<String>The text to use for an ignore file directive (ex. <!-- dprint-ignore-file -->).
Default: "dprint-ignore-file"
See: https://dprint.dev/plugins/markdown/config/#ignoreFileDirective
ignore_start_directive: Option<String>The text to use for an ignore start directive (ex. <!-- dprint-ignore-start -->).
Default: "dprint-ignore-start"
See: https://dprint.dev/plugins/markdown/config/#ignoreStartDirective
line_width: Option<u32>The width of a line the printer will try to stay under. Note that the printer may exceed this width in certain cases.
Default: 80
new_line_kind: Option<NewLineKind>The kind of newline to use.
Default: "lf"
See: https://dprint.dev/plugins/markdown/config/#newLineKind
strong_kind: Option<StrongKind>The character to use for strong emphasis/bold.
Default: "asterisks"
Custom tag to file extension mappings for formatting code blocks. For example: { “markdown”: “md” }
text_wrap: Option<TextWrap>Text wrapping possibilities.
Default: "maintain"
unordered_list_kind: Option<UnorderedListKind>The character to use for unordered lists.
Default: "dashes"
See: https://dprint.dev/plugins/markdown/config/#unorderedListKind
extra: BTreeMap<String, Value>Additional plugin-specific settings not covered by the typed fields.