pub struct TypeScriptConfig {Show 186 fields
pub locked: Option<bool>,
pub associations: Option<Vec<String>>,
pub arguments_prefer_hanging: Option<PreferHanging>,
pub arguments_prefer_single_line: Option<bool>,
pub arguments_space_around: Option<bool>,
pub arguments_trailing_commas: Option<TrailingCommas>,
pub array_expression_prefer_hanging: Option<PreferHanging>,
pub array_expression_prefer_single_line: Option<bool>,
pub array_expression_space_around: Option<bool>,
pub array_expression_trailing_commas: Option<TrailingCommas>,
pub array_pattern_prefer_hanging: Option<bool>,
pub array_pattern_prefer_single_line: Option<bool>,
pub array_pattern_space_around: Option<bool>,
pub array_pattern_trailing_commas: Option<TrailingCommas>,
pub arrow_function_brace_position: Option<BracePosition>,
pub arrow_function_use_parentheses: Option<UseParentheses>,
pub binary_expression_line_per_expression: Option<bool>,
pub binary_expression_operator_position: Option<OperatorPosition>,
pub binary_expression_prefer_single_line: Option<bool>,
pub binary_expression_space_surrounding_bitwise_and_arithmetic_operator: Option<bool>,
pub brace_position: Option<BracePosition>,
pub catch_clause_space_around: Option<bool>,
pub class_declaration_brace_position: Option<BracePosition>,
pub class_expression_brace_position: Option<BracePosition>,
pub comment_line_force_space_after_slashes: Option<bool>,
pub computed_prefer_single_line: Option<bool>,
pub conditional_expression_operator_position: Option<OperatorPosition>,
pub conditional_expression_prefer_single_line: Option<bool>,
pub conditional_type_operator_position: Option<OperatorPosition>,
pub conditional_type_prefer_single_line: Option<bool>,
pub construct_signature_space_after_new_keyword: Option<bool>,
pub constructor_brace_position: Option<BracePosition>,
pub constructor_space_before_parentheses: Option<bool>,
pub constructor_type_space_after_new_keyword: Option<bool>,
pub decorators_prefer_single_line: Option<bool>,
pub deno: Option<bool>,
pub do_while_statement_brace_position: Option<BracePosition>,
pub do_while_statement_next_control_flow_position: Option<OperatorPosition>,
pub do_while_statement_prefer_hanging: Option<bool>,
pub do_while_statement_space_after_while_keyword: Option<bool>,
pub do_while_statement_space_around: Option<bool>,
pub enum_declaration_brace_position: Option<BracePosition>,
pub enum_declaration_member_spacing: Option<MemberSpacing>,
pub enum_declaration_trailing_commas: Option<TrailingCommas>,
pub export_declaration_force_multi_line: Option<ForceMultiLine>,
pub export_declaration_force_single_line: Option<bool>,
pub export_declaration_prefer_hanging: Option<bool>,
pub export_declaration_prefer_single_line: Option<bool>,
pub export_declaration_sort_named_exports: Option<SortImportDeclarations>,
pub export_declaration_sort_type_only_exports: Option<SortTypeOnlyExports>,
pub export_declaration_space_surrounding_named_exports: Option<bool>,
pub export_declaration_trailing_commas: Option<TrailingCommas>,
pub extends_clause_prefer_hanging: Option<bool>,
pub for_in_statement_brace_position: Option<BracePosition>,
pub for_in_statement_prefer_hanging: Option<bool>,
pub for_in_statement_single_body_position: Option<OperatorPosition>,
pub for_in_statement_space_after_for_keyword: Option<bool>,
pub for_in_statement_space_around: Option<bool>,
pub for_in_statement_use_braces: Option<UseBraces>,
pub for_of_statement_brace_position: Option<BracePosition>,
pub for_of_statement_prefer_hanging: Option<bool>,
pub for_of_statement_single_body_position: Option<OperatorPosition>,
pub for_of_statement_space_after_for_keyword: Option<bool>,
pub for_of_statement_space_around: Option<bool>,
pub for_of_statement_use_braces: Option<UseBraces>,
pub for_statement_brace_position: Option<BracePosition>,
pub for_statement_prefer_hanging: Option<bool>,
pub for_statement_prefer_single_line: Option<bool>,
pub for_statement_single_body_position: Option<OperatorPosition>,
pub for_statement_space_after_for_keyword: Option<bool>,
pub for_statement_space_after_semi_colons: Option<bool>,
pub for_statement_space_around: Option<bool>,
pub for_statement_use_braces: Option<UseBraces>,
pub function_declaration_brace_position: Option<BracePosition>,
pub function_declaration_space_before_parentheses: Option<bool>,
pub function_expression_brace_position: Option<BracePosition>,
pub function_expression_space_after_function_keyword: Option<bool>,
pub function_expression_space_before_parentheses: Option<bool>,
pub get_accessor_brace_position: Option<BracePosition>,
pub get_accessor_space_before_parentheses: Option<bool>,
pub if_statement_brace_position: Option<BracePosition>,
pub if_statement_next_control_flow_position: Option<OperatorPosition>,
pub if_statement_prefer_hanging: Option<bool>,
pub if_statement_single_body_position: Option<OperatorPosition>,
pub if_statement_space_after_if_keyword: Option<bool>,
pub if_statement_space_around: Option<bool>,
pub if_statement_use_braces: Option<UseBraces>,
pub ignore_file_comment_text: Option<String>,
pub ignore_node_comment_text: Option<String>,
pub implements_clause_prefer_hanging: Option<bool>,
pub import_declaration_force_multi_line: Option<ForceMultiLine>,
pub import_declaration_force_single_line: Option<bool>,
pub import_declaration_prefer_hanging: Option<bool>,
pub import_declaration_prefer_single_line: Option<bool>,
pub import_declaration_sort_named_imports: Option<SortImportDeclarations>,
pub import_declaration_sort_type_only_imports: Option<SortTypeOnlyExports>,
pub import_declaration_space_surrounding_named_imports: Option<bool>,
pub import_declaration_trailing_commas: Option<TrailingCommas>,
pub indent_width: Option<u32>,
pub interface_declaration_brace_position: Option<BracePosition>,
pub jsx_bracket_position: Option<OperatorPosition>,
pub jsx_force_new_lines_surrounding_content: Option<bool>,
pub jsx_multi_line_parens: Option<MultiLineParens>,
pub jsx_quote_style: Option<QuoteStyleKind>,
pub jsx_attributes_prefer_hanging: Option<bool>,
pub jsx_attributes_prefer_single_line: Option<bool>,
pub jsx_element_prefer_single_line: Option<bool>,
pub jsx_expression_container_space_surrounding_expression: Option<bool>,
pub jsx_opening_element_bracket_position: Option<OperatorPosition>,
pub jsx_self_closing_element_bracket_position: Option<OperatorPosition>,
pub jsx_self_closing_element_space_before_slash: Option<bool>,
pub line_width: Option<u32>,
pub mapped_type_prefer_single_line: Option<bool>,
pub member_expression_line_per_expression: Option<bool>,
pub member_expression_prefer_single_line: Option<bool>,
pub method_brace_position: Option<BracePosition>,
pub method_space_before_parentheses: Option<bool>,
pub module_sort_export_declarations: Option<SortImportDeclarations>,
pub module_sort_import_declarations: Option<SortImportDeclarations>,
pub module_declaration_brace_position: Option<BracePosition>,
pub new_line_kind: Option<NewLineKind>,
pub next_control_flow_position: Option<OperatorPosition>,
pub object_expression_prefer_hanging: Option<bool>,
pub object_expression_prefer_single_line: Option<bool>,
pub object_expression_space_surrounding_properties: Option<bool>,
pub object_expression_trailing_commas: Option<TrailingCommas>,
pub object_pattern_prefer_hanging: Option<bool>,
pub object_pattern_prefer_single_line: Option<bool>,
pub object_pattern_space_surrounding_properties: Option<bool>,
pub object_pattern_trailing_commas: Option<TrailingCommas>,
pub operator_position: Option<OperatorPosition>,
pub parameters_prefer_hanging: Option<PreferHanging>,
pub parameters_prefer_single_line: Option<bool>,
pub parameters_space_around: Option<bool>,
pub parameters_trailing_commas: Option<TrailingCommas>,
pub paren_expression_space_around: Option<bool>,
pub parentheses_prefer_single_line: Option<bool>,
pub prefer_hanging: Option<bool>,
pub prefer_single_line: Option<bool>,
pub quote_props: Option<QuoteProps>,
pub quote_style: Option<QuoteStyle>,
pub semi_colons: Option<SemiColons>,
pub sequence_expression_prefer_hanging: Option<bool>,
pub set_accessor_brace_position: Option<BracePosition>,
pub set_accessor_space_before_parentheses: Option<bool>,
pub single_body_position: Option<OperatorPosition>,
pub space_around: Option<bool>,
pub space_surrounding_properties: Option<bool>,
pub static_block_brace_position: Option<BracePosition>,
pub switch_case_brace_position: Option<BracePosition>,
pub switch_statement_brace_position: Option<BracePosition>,
pub switch_statement_prefer_hanging: Option<bool>,
pub switch_statement_space_around: Option<bool>,
pub tagged_template_space_before_literal: Option<bool>,
pub trailing_commas: Option<TrailingCommas>,
pub try_statement_brace_position: Option<BracePosition>,
pub try_statement_next_control_flow_position: Option<OperatorPosition>,
pub tuple_type_prefer_hanging: Option<PreferHanging>,
pub tuple_type_prefer_single_line: Option<bool>,
pub tuple_type_space_around: Option<bool>,
pub tuple_type_trailing_commas: Option<TrailingCommas>,
pub type_annotation_space_before_colon: Option<bool>,
pub type_assertion_space_before_expression: Option<bool>,
pub type_literal_prefer_hanging: Option<bool>,
pub type_literal_prefer_single_line: Option<bool>,
pub type_literal_separator_kind: Option<SeparatorKind>,
pub type_literal_separator_kind_multi_line: Option<SeparatorKind>,
pub type_literal_separator_kind_single_line: Option<SeparatorKind>,
pub type_literal_space_surrounding_properties: Option<bool>,
pub type_literal_trailing_commas: Option<TrailingCommas>,
pub type_parameters_prefer_hanging: Option<PreferHanging>,
pub type_parameters_prefer_single_line: Option<bool>,
pub type_parameters_trailing_commas: Option<TrailingCommas>,
pub union_and_intersection_type_prefer_hanging: Option<bool>,
pub union_and_intersection_type_prefer_single_line: Option<bool>,
pub use_braces: Option<UseBraces>,
pub use_tabs: Option<bool>,
pub variable_statement_prefer_hanging: Option<bool>,
pub variable_statement_prefer_single_line: Option<bool>,
pub while_statement_brace_position: Option<BracePosition>,
pub while_statement_prefer_hanging: Option<bool>,
pub while_statement_single_body_position: Option<OperatorPosition>,
pub while_statement_space_after_while_keyword: Option<bool>,
pub while_statement_space_around: Option<bool>,
pub while_statement_use_braces: Option<UseBraces>,
pub extra: BTreeMap<String, Value>,
}Expand description
Configuration for the dprint TypeScript / JavaScript plugin.
Fields
locked: Option<bool>Whether the configuration is not allowed to be overridden or extended.
associations: Option<Vec<String>>File patterns to associate with this plugin.
arguments_prefer_hanging: Option<PreferHanging>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: "never"
See: https://dprint.dev/plugins/typescript/config/#argumentspreferHanging
arguments_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#argumentspreferSingleLine
arguments_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#argumentsspaceAround
arguments_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#argumentstrailingCommas
array_expression_prefer_hanging: Option<PreferHanging>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: "never"
See: https://dprint.dev/plugins/typescript/config/#arrayExpressionpreferHanging
array_expression_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#arrayExpressionpreferSingleLine
array_expression_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#arrayExpressionspaceAround
array_expression_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#arrayExpressiontrailingCommas
array_pattern_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#arrayPatternpreferHanging
array_pattern_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#arrayPatternpreferSingleLine
array_pattern_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#arrayPatternspaceAround
array_pattern_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#arrayPatterntrailingCommas
arrow_function_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#arrowFunctionbracePosition
arrow_function_use_parentheses: Option<UseParentheses>Whether to use parentheses around a single parameter in an arrow function.
Default: "maintain"
See: https://dprint.dev/plugins/typescript/config/#arrowFunctionuseParentheses
binary_expression_line_per_expression: Option<bool>Whether to force a line per expression when spanning multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#binaryExpressionlinePerExpression
binary_expression_operator_position: Option<OperatorPosition>Where to place the operator for expressions that span multiple lines.
Default: "nextLine"
See: https://dprint.dev/plugins/typescript/config/#binaryExpressionoperatorPosition
binary_expression_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#binaryExpressionpreferSingleLine
binary_expression_space_surrounding_bitwise_and_arithmetic_operator: Option<bool>Whether to surround the operator in a binary expression with spaces.
Default: true
brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#bracePosition
catch_clause_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#catchClausespaceAround
class_declaration_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#classDeclarationbracePosition
class_expression_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#classExpressionbracePosition
comment_line_force_space_after_slashes: Option<bool>Forces a space after the double slash in a comment line.
Default: true
See: https://dprint.dev/plugins/typescript/config/#commentLineforceSpaceAfterSlashes
computed_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#computedpreferSingleLine
conditional_expression_operator_position: Option<OperatorPosition>Where to place the operator for expressions that span multiple lines.
Default: "nextLine"
See: https://dprint.dev/plugins/typescript/config/#conditionalExpressionoperatorPosition
conditional_expression_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#conditionalExpressionpreferSingleLine
conditional_type_operator_position: Option<OperatorPosition>Where to place the operator for expressions that span multiple lines.
Default: "nextLine"
See: https://dprint.dev/plugins/typescript/config/#conditionalTypeoperatorPosition
conditional_type_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#conditionalTypepreferSingleLine
construct_signature_space_after_new_keyword: Option<bool>Whether to add a space after the new keyword in a construct signature.
Default: false
See: https://dprint.dev/plugins/typescript/config/#constructSignaturespaceAfterNewKeyword
constructor_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#constructorbracePosition
constructor_space_before_parentheses: Option<bool>Whether to add a space before the parentheses of a constructor.
Default: false
See: https://dprint.dev/plugins/typescript/config/#constructorspaceBeforeParentheses
constructor_type_space_after_new_keyword: Option<bool>Whether to add a space after the new keyword in a constructor type.
Default: false
See: https://dprint.dev/plugins/typescript/config/#constructorTypespaceAfterNewKeyword
decorators_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#decoratorspreferSingleLine
deno: Option<bool>Top level configuration that sets the configuration to what is used in Deno.
Default: false
do_while_statement_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#doWhileStatementbracePosition
do_while_statement_next_control_flow_position: Option<OperatorPosition>Where to place the next control flow within a control flow statement.
Default: "sameLine"
See: https://dprint.dev/plugins/typescript/config/#doWhileStatementnextControlFlowPosition
do_while_statement_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#doWhileStatementpreferHanging
do_while_statement_space_after_while_keyword: Option<bool>Whether to add a space after the while keyword in a do while statement.
Default: true
See: https://dprint.dev/plugins/typescript/config/#doWhileStatementspaceAfterWhileKeyword
do_while_statement_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#doWhileStatementspaceAround
enum_declaration_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#enumDeclarationbracePosition
enum_declaration_member_spacing: Option<MemberSpacing>How to space the members of an enum.
Default: "maintain"
See: https://dprint.dev/plugins/typescript/config/#enumDeclarationmemberSpacing
enum_declaration_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#enumDeclarationtrailingCommas
export_declaration_force_multi_line: Option<ForceMultiLine>If code import/export specifiers should be forced to be on multiple lines.
Default: "never"
See: https://dprint.dev/plugins/typescript/config/#exportDeclarationforceMultiLine
export_declaration_force_single_line: Option<bool>If code should be forced to be on a single line if able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#exportDeclarationforceSingleLine
export_declaration_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#exportDeclarationpreferHanging
export_declaration_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#exportDeclarationpreferSingleLine
export_declaration_sort_named_exports: Option<SortImportDeclarations>The kind of sort ordering to use.
Default: "caseInsensitive"
See: https://dprint.dev/plugins/typescript/config/#exportDeclarationsortNamedExports
export_declaration_sort_type_only_exports: Option<SortTypeOnlyExports>The kind of sort ordering to use for typed imports and exports.
Default: "none"
See: https://dprint.dev/plugins/typescript/config/#exportDeclarationsortTypeOnlyExports
export_declaration_space_surrounding_named_exports: Option<bool>Whether to add spaces around named exports in an export declaration.
Default: true
See: https://dprint.dev/plugins/typescript/config/#exportDeclarationspaceSurroundingNamedExports
export_declaration_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#exportDeclarationtrailingCommas
extends_clause_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#extendsClausepreferHanging
for_in_statement_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#forInStatementbracePosition
for_in_statement_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#forInStatementpreferHanging
for_in_statement_single_body_position: Option<OperatorPosition>Where to place the expression of a statement that could possibly be on one line (ex. if (true) console.log(5);).
Default: "maintain"
See: https://dprint.dev/plugins/typescript/config/#forInStatementsingleBodyPosition
for_in_statement_space_after_for_keyword: Option<bool>Whether to add a space after the for keyword in a “for in” statement.
Default: true
See: https://dprint.dev/plugins/typescript/config/#forInStatementspaceAfterForKeyword
for_in_statement_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#forInStatementspaceAround
for_in_statement_use_braces: Option<UseBraces>If braces should be used or not.
Default: "whenNotSingleLine"
See: https://dprint.dev/plugins/typescript/config/#forInStatementuseBraces
for_of_statement_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#forOfStatementbracePosition
for_of_statement_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#forOfStatementpreferHanging
for_of_statement_single_body_position: Option<OperatorPosition>Where to place the expression of a statement that could possibly be on one line (ex. if (true) console.log(5);).
Default: "maintain"
See: https://dprint.dev/plugins/typescript/config/#forOfStatementsingleBodyPosition
for_of_statement_space_after_for_keyword: Option<bool>Whether to add a space after the for keyword in a “for of” statement.
Default: true
See: https://dprint.dev/plugins/typescript/config/#forOfStatementspaceAfterForKeyword
for_of_statement_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#forOfStatementspaceAround
for_of_statement_use_braces: Option<UseBraces>If braces should be used or not.
Default: "whenNotSingleLine"
See: https://dprint.dev/plugins/typescript/config/#forOfStatementuseBraces
for_statement_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#forStatementbracePosition
for_statement_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#forStatementpreferHanging
for_statement_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#forStatementpreferSingleLine
for_statement_single_body_position: Option<OperatorPosition>Where to place the expression of a statement that could possibly be on one line (ex. if (true) console.log(5);).
Default: "maintain"
See: https://dprint.dev/plugins/typescript/config/#forStatementsingleBodyPosition
for_statement_space_after_for_keyword: Option<bool>Whether to add a space after the for keyword in a “for” statement.
Default: true
See: https://dprint.dev/plugins/typescript/config/#forStatementspaceAfterForKeyword
for_statement_space_after_semi_colons: Option<bool>Whether to add a space after the semi-colons in a “for” statement.
Default: true
See: https://dprint.dev/plugins/typescript/config/#forStatementspaceAfterSemiColons
for_statement_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#forStatementspaceAround
for_statement_use_braces: Option<UseBraces>If braces should be used or not.
Default: "whenNotSingleLine"
See: https://dprint.dev/plugins/typescript/config/#forStatementuseBraces
function_declaration_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#functionDeclarationbracePosition
function_declaration_space_before_parentheses: Option<bool>Whether to add a space before the parentheses of a function declaration.
Default: false
See: https://dprint.dev/plugins/typescript/config/#functionDeclarationspaceBeforeParentheses
function_expression_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#functionExpressionbracePosition
function_expression_space_after_function_keyword: Option<bool>Whether to add a space after the function keyword of a function expression.
Default: false
See: https://dprint.dev/plugins/typescript/config/#functionExpressionspaceAfterFunctionKeyword
function_expression_space_before_parentheses: Option<bool>Whether to add a space before the parentheses of a function expression.
Default: false
See: https://dprint.dev/plugins/typescript/config/#functionExpressionspaceBeforeParentheses
get_accessor_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#getAccessorbracePosition
get_accessor_space_before_parentheses: Option<bool>Whether to add a space before the parentheses of a get accessor.
Default: false
See: https://dprint.dev/plugins/typescript/config/#getAccessorspaceBeforeParentheses
if_statement_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#ifStatementbracePosition
if_statement_next_control_flow_position: Option<OperatorPosition>Where to place the next control flow within a control flow statement.
Default: "sameLine"
See: https://dprint.dev/plugins/typescript/config/#ifStatementnextControlFlowPosition
if_statement_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#ifStatementpreferHanging
if_statement_single_body_position: Option<OperatorPosition>Where to place the expression of a statement that could possibly be on one line (ex. if (true) console.log(5);).
Default: "maintain"
See: https://dprint.dev/plugins/typescript/config/#ifStatementsingleBodyPosition
if_statement_space_after_if_keyword: Option<bool>Whether to add a space after the if keyword in an “if” statement.
Default: true
See: https://dprint.dev/plugins/typescript/config/#ifStatementspaceAfterIfKeyword
if_statement_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#ifStatementspaceAround
if_statement_use_braces: Option<UseBraces>If braces should be used or not.
Default: "whenNotSingleLine"
See: https://dprint.dev/plugins/typescript/config/#ifStatementuseBraces
ignore_file_comment_text: Option<String>The text to use for a file ignore comment (ex. // dprint-ignore-file).
Default: "dprint-ignore-file"
See: https://dprint.dev/plugins/typescript/config/#ignoreFileCommentText
ignore_node_comment_text: Option<String>The text to use for an ignore comment (ex. // dprint-ignore).
Default: "dprint-ignore"
See: https://dprint.dev/plugins/typescript/config/#ignoreNodeCommentText
implements_clause_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#implementsClausepreferHanging
import_declaration_force_multi_line: Option<ForceMultiLine>If code import/export specifiers should be forced to be on multiple lines.
Default: "never"
See: https://dprint.dev/plugins/typescript/config/#importDeclarationforceMultiLine
import_declaration_force_single_line: Option<bool>If code should be forced to be on a single line if able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#importDeclarationforceSingleLine
import_declaration_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#importDeclarationpreferHanging
import_declaration_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#importDeclarationpreferSingleLine
import_declaration_sort_named_imports: Option<SortImportDeclarations>The kind of sort ordering to use.
Default: "caseInsensitive"
See: https://dprint.dev/plugins/typescript/config/#importDeclarationsortNamedImports
import_declaration_sort_type_only_imports: Option<SortTypeOnlyExports>The kind of sort ordering to use for typed imports and exports.
Default: "none"
See: https://dprint.dev/plugins/typescript/config/#importDeclarationsortTypeOnlyImports
import_declaration_space_surrounding_named_imports: Option<bool>Whether to add spaces around named imports in an import declaration.
Default: true
See: https://dprint.dev/plugins/typescript/config/#importDeclarationspaceSurroundingNamedImports
import_declaration_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#importDeclarationtrailingCommas
indent_width: Option<u32>The number of columns for an indent.
Default: 2
See: https://dprint.dev/plugins/typescript/config/#indentWidth
interface_declaration_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#interfaceDeclarationbracePosition
jsx_bracket_position: Option<OperatorPosition>If the end angle bracket of a jsx open element or self closing element should be on the same or next line when the attributes span multiple lines.
Default: "nextLine"
See: https://dprint.dev/plugins/typescript/config/#jsxbracketPosition
jsx_force_new_lines_surrounding_content: Option<bool>Forces newlines surrounding the content of JSX elements.
Default: false
See: https://dprint.dev/plugins/typescript/config/#jsxforceNewLinesSurroundingContent
jsx_multi_line_parens: Option<MultiLineParens>Surrounds the top-most JSX element or fragment in parentheses when it spans multiple lines.
Default: "prefer"
See: https://dprint.dev/plugins/typescript/config/#jsxmultiLineParens
jsx_quote_style: Option<QuoteStyleKind>How to use single or double quotes in JSX attributes.
Default: "preferDouble"
See: https://dprint.dev/plugins/typescript/config/#jsxquoteStyle
jsx_attributes_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#jsxAttributespreferHanging
jsx_attributes_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#jsxAttributespreferSingleLine
jsx_element_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#jsxElementpreferSingleLine
jsx_expression_container_space_surrounding_expression: Option<bool>Whether to add a space surrounding the expression of a JSX container.
Default: false
See: https://dprint.dev/plugins/typescript/config/#jsxExpressionContainerspaceSurroundingExpression
jsx_opening_element_bracket_position: Option<OperatorPosition>If the end angle bracket of a jsx open element or self closing element should be on the same or next line when the attributes span multiple lines.
Default: "nextLine"
See: https://dprint.dev/plugins/typescript/config/#jsxOpeningElementbracketPosition
jsx_self_closing_element_bracket_position: Option<OperatorPosition>If the end angle bracket of a jsx open element or self closing element should be on the same or next line when the attributes span multiple lines.
Default: "nextLine"
See: https://dprint.dev/plugins/typescript/config/#jsxSelfClosingElementbracketPosition
jsx_self_closing_element_space_before_slash: Option<bool>Whether to add a space before a JSX element’s slash when self closing.
Default: true
See: https://dprint.dev/plugins/typescript/config/#jsxSelfClosingElementspaceBeforeSlash
line_width: Option<u32>The width of a line the printer will try to stay under. Note that the printer may exceed this width in certain cases.
Default: 120
See: https://dprint.dev/plugins/typescript/config/#lineWidth
mapped_type_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#mappedTypepreferSingleLine
member_expression_line_per_expression: Option<bool>Whether to force a line per expression when spanning multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#memberExpressionlinePerExpression
member_expression_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#memberExpressionpreferSingleLine
method_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#methodbracePosition
method_space_before_parentheses: Option<bool>Whether to add a space before the parentheses of a method.
Default: false
See: https://dprint.dev/plugins/typescript/config/#methodspaceBeforeParentheses
module_sort_export_declarations: Option<SortImportDeclarations>The kind of sort ordering to use.
Default: "caseInsensitive"
See: https://dprint.dev/plugins/typescript/config/#modulesortExportDeclarations
module_sort_import_declarations: Option<SortImportDeclarations>The kind of sort ordering to use.
Default: "caseInsensitive"
See: https://dprint.dev/plugins/typescript/config/#modulesortImportDeclarations
module_declaration_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#moduleDeclarationbracePosition
new_line_kind: Option<NewLineKind>The kind of newline to use.
Default: "lf"
See: https://dprint.dev/plugins/typescript/config/#newLineKind
next_control_flow_position: Option<OperatorPosition>Where to place the next control flow within a control flow statement.
Default: "sameLine"
See: https://dprint.dev/plugins/typescript/config/#nextControlFlowPosition
object_expression_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#objectExpressionpreferHanging
object_expression_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#objectExpressionpreferSingleLine
object_expression_space_surrounding_properties: Option<bool>Whether to add a space surrounding the properties of a single line object expression.
Default: true
See: https://dprint.dev/plugins/typescript/config/#objectExpressionspaceSurroundingProperties
object_expression_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#objectExpressiontrailingCommas
object_pattern_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#objectPatternpreferHanging
object_pattern_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#objectPatternpreferSingleLine
object_pattern_space_surrounding_properties: Option<bool>Whether to add a space surrounding the properties of a single line object pattern.
Default: true
See: https://dprint.dev/plugins/typescript/config/#objectPatternspaceSurroundingProperties
object_pattern_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#objectPatterntrailingCommas
operator_position: Option<OperatorPosition>Where to place the operator for expressions that span multiple lines.
Default: "nextLine"
See: https://dprint.dev/plugins/typescript/config/#operatorPosition
parameters_prefer_hanging: Option<PreferHanging>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: "never"
See: https://dprint.dev/plugins/typescript/config/#parameterspreferHanging
parameters_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#parameterspreferSingleLine
parameters_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#parametersspaceAround
parameters_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#parameterstrailingCommas
paren_expression_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#parenExpressionspaceAround
parentheses_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#parenthesespreferSingleLine
prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#preferHanging
prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#preferSingleLine
quote_props: Option<QuoteProps>Change when properties in objects are quoted.
Default: "preserve"
See: https://dprint.dev/plugins/typescript/config/#quoteProps
quote_style: Option<QuoteStyle>How to use single or double quotes.
Default: "alwaysDouble"
See: https://dprint.dev/plugins/typescript/config/#quoteStyle
semi_colons: Option<SemiColons>How semi-colons should be used.
Default: "prefer"
See: https://dprint.dev/plugins/typescript/config/#semiColons
sequence_expression_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#sequenceExpressionpreferHanging
set_accessor_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#setAccessorbracePosition
set_accessor_space_before_parentheses: Option<bool>Whether to add a space before the parentheses of a set accessor.
Default: false
See: https://dprint.dev/plugins/typescript/config/#setAccessorspaceBeforeParentheses
single_body_position: Option<OperatorPosition>Where to place the expression of a statement that could possibly be on one line (ex. if (true) console.log(5);).
Default: "maintain"
See: https://dprint.dev/plugins/typescript/config/#singleBodyPosition
space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#spaceAround
space_surrounding_properties: Option<bool>Whether to add a space surrounding the properties of single line object-like nodes.
Default: true
See: https://dprint.dev/plugins/typescript/config/#spaceSurroundingProperties
static_block_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#staticBlockbracePosition
switch_case_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#switchCasebracePosition
switch_statement_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#switchStatementbracePosition
switch_statement_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#switchStatementpreferHanging
switch_statement_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#switchStatementspaceAround
tagged_template_space_before_literal: Option<bool>Whether to add a space before the literal in a tagged template.
Default: false
See: https://dprint.dev/plugins/typescript/config/#taggedTemplatespaceBeforeLiteral
trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#trailingCommas
try_statement_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#tryStatementbracePosition
try_statement_next_control_flow_position: Option<OperatorPosition>Where to place the next control flow within a control flow statement.
Default: "sameLine"
See: https://dprint.dev/plugins/typescript/config/#tryStatementnextControlFlowPosition
tuple_type_prefer_hanging: Option<PreferHanging>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: "never"
See: https://dprint.dev/plugins/typescript/config/#tupleTypepreferHanging
tuple_type_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#tupleTypepreferSingleLine
tuple_type_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#tupleTypespaceAround
tuple_type_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#tupleTypetrailingCommas
type_annotation_space_before_colon: Option<bool>Whether to add a space before the colon of a type annotation.
Default: false
See: https://dprint.dev/plugins/typescript/config/#typeAnnotationspaceBeforeColon
type_assertion_space_before_expression: Option<bool>Whether to add a space before the expression in a type assertion.
Default: true
See: https://dprint.dev/plugins/typescript/config/#typeAssertionspaceBeforeExpression
type_literal_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#typeLiteralpreferHanging
type_literal_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#typeLiteralpreferSingleLine
type_literal_separator_kind: Option<SeparatorKind>The kind of separator to use in type literals.
Default: "semiColon"
See: https://dprint.dev/plugins/typescript/config/#typeLiteralseparatorKind
type_literal_separator_kind_multi_line: Option<SeparatorKind>The kind of separator to use in type literals.
Default: "semiColon"
See: https://dprint.dev/plugins/typescript/config/#typeLiteralseparatorKindmultiLine
type_literal_separator_kind_single_line: Option<SeparatorKind>The kind of separator to use in type literals.
Default: "semiColon"
See: https://dprint.dev/plugins/typescript/config/#typeLiteralseparatorKindsingleLine
type_literal_space_surrounding_properties: Option<bool>Whether to add a space surrounding the properties of a single line type literal.
Default: true
See: https://dprint.dev/plugins/typescript/config/#typeLiteralspaceSurroundingProperties
type_literal_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#typeLiteraltrailingCommas
type_parameters_prefer_hanging: Option<PreferHanging>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: "never"
See: https://dprint.dev/plugins/typescript/config/#typeParameterspreferHanging
type_parameters_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#typeParameterspreferSingleLine
type_parameters_trailing_commas: Option<TrailingCommas>If trailing commas should be used.
Default: "onlyMultiLine"
See: https://dprint.dev/plugins/typescript/config/#typeParameterstrailingCommas
union_and_intersection_type_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#unionAndIntersectionTypepreferHanging
union_and_intersection_type_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#unionAndIntersectionTypepreferSingleLine
use_braces: Option<UseBraces>If braces should be used or not.
Default: "whenNotSingleLine"
See: https://dprint.dev/plugins/typescript/config/#useBraces
use_tabs: Option<bool>Whether to use tabs (true) or spaces (false).
Default: false
variable_statement_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#variableStatementpreferHanging
variable_statement_prefer_single_line: Option<bool>If code should revert back from being on multiple lines to being on a single line when able.
Default: false
See: https://dprint.dev/plugins/typescript/config/#variableStatementpreferSingleLine
while_statement_brace_position: Option<BracePosition>Where to place the opening brace.
Default: "sameLineUnlessHanging"
See: https://dprint.dev/plugins/typescript/config/#whileStatementbracePosition
while_statement_prefer_hanging: Option<bool>Set to prefer hanging indentation when exceeding the line width instead of making code split up on multiple lines.
Default: false
See: https://dprint.dev/plugins/typescript/config/#whileStatementpreferHanging
while_statement_single_body_position: Option<OperatorPosition>Where to place the expression of a statement that could possibly be on one line (ex. if (true) console.log(5);).
Default: "maintain"
See: https://dprint.dev/plugins/typescript/config/#whileStatementsingleBodyPosition
while_statement_space_after_while_keyword: Option<bool>Whether to add a space after the while keyword in a while statement.
Default: true
See: https://dprint.dev/plugins/typescript/config/#whileStatementspaceAfterWhileKeyword
while_statement_space_around: Option<bool>Whether to place spaces around enclosed expressions.
Default: false
See: https://dprint.dev/plugins/typescript/config/#whileStatementspaceAround
while_statement_use_braces: Option<UseBraces>If braces should be used or not.
Default: "whenNotSingleLine"
See: https://dprint.dev/plugins/typescript/config/#whileStatementuseBraces
extra: BTreeMap<String, Value>Additional plugin-specific settings not covered by the typed fields.